;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "yaml-imenu" "20250818.1432"
  "Enhancement of the imenu support in yaml-mode."
  '((emacs     "27.1")
    (yaml-mode "0"))
  :url "https://github.com/knu/yaml-imenu.el"
  :commit "c2f32557c11cbd402853104da8f644df4ee88434"
  :revdesc "c2f32557c11c"
  :keywords '("outlining" "convenience" "imenu")
  :authors '(("Akinori MUSHA" . "knu@iDaemons.org"))
  :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
